@@ -10,7 +10,6 @@ from controller.utils.singletons.models import SingletonModel
 from pki import ca, Bob
 
 from . import settings
-from .utils import get_mgmt_backend_class
 from .validators import (validate_sliver_mac_prefix, validate_ipv4_range,
         validate_dhcp_range, validate_priv_ipv4_prefix)
 
@@ -34,6 +33,7 @@ class Node(models.Model):
     NONE = 'none'
     DHCP = 'dhcp'
     AUTO = 'auto'
+    RANGE = 'range'
     IPV6_METHODS = (
         (NONE, 'None'),
         (DHCP, 'DHCP'),
@@ -42,7 +42,7 @@ class Node(models.Model):
     IPV4_METHODS = (
         (NONE, 'None'),
         (DHCP, 'DHCP'),
-        (AUTO, 'Auto'),
+        (RANGE, 'Range'),
     )
     
     name = models.CharField(max_length=256, unique=True,
@@ -76,14 +76,14 @@ class Node(models.Model):
                       'local network (see <a href="https://wiki.confine-project.eu/'
                       'arch:node">node architecture</a>). Possible values: none (no '
                       'public IPv4 support), dhcp (addresses configured using DHCP), '
-                      'range (addresses chosen from a range, see sliver_pub_ipv4_range).')
+                      'range (addresses chosen from a range, see <em>Sliver public IPv4 range</em>).')
     sliver_pub_ipv4_range = NullableCharField('Sliver public IPv4 range', max_length=256,
             blank=True, null=True, default=settings.NODES_NODE_SLIVER_PUB_IPV4_RANGE_DFLT,
             help_text='Describes the public IPv4 range that can be used by sliver '
-                      'public interfaces. If /sliver_pub_ipv4 is none, its value is '
-                      'null. If /sliver_pub_ipv4 is dhcp, its value is #N, where N '
+                      'public interfaces. If <em>Sliver public IPv4</em> is <em>none</em>, its value is '
+                      'null. If <em>Sliver public IPv4</em> is <em>dhcp</em>, its value is <em>#N</em>, where N '
                       'is the decimal integer number of DHCP addresses reserved for '
-                      'slivers. If /sliver_pub_ipv4 is range, its value is BASE_IP#N, '
+                      'slivers. If <em>Sliver public IPv4</em> is <em>range</em>, its value is <em>BASE_IP#N</em>, '
                       'where N is the decimal integer number of consecutive addresses '
                       'reserved for slivers after and including the range\'s base '
                       'address BASE_IP (an IP address in the local network).')
@@ -92,7 +92,7 @@ class Node(models.Model):
             help_text='A 16-bit integer number in 0x-prefixed hexadecimal notation '
                       'used as the node sliver MAC prefix. See <a href="http://wiki.'
                       'confine-project.eu/arch:addressing">addressing</a> for legal '
-                      'values. %s when null.</a>.' % SLIVER_MAC_PREFIX_DFLT)
+                      'values. %s when null.' % SLIVER_MAC_PREFIX_DFLT)
     priv_ipv4_prefix = NullableCharField('Private IPv4 prefix', null=True,
             blank=True, max_length=19, validators=[validate_priv_ipv4_prefix],
             help_text='IPv4 /24 network in CIDR notation used as a node private IPv4 '
@@ -119,6 +119,7 @@ class Node(models.Model):
                       'Node and group administrators in this group are able to '
                       'manage this node.')
     island = models.ForeignKey('nodes.Island', null=True, blank=True,
+            on_delete=models.SET_NULL,
             help_text='An optional island used to hint where the node is located '
                       'network-wise.')
     
@@ -140,13 +141,13 @@ class Node(models.Model):
         elif self.set_state != Node.DEBUG:
             raise ValidationError("Initial state must be Debug")
         # clean sliver_pub_ipv4 and _range
-        if self.sliver_pub_ipv4 == 'none':
+        if self.sliver_pub_ipv4 == Node.NONE:
             if self.sliver_pub_ipv4_range:
                 msg = "Sliver pub IPv4 range must be empty when sliver pub IPv4 is none"
                 raise ValidationError(msg)
-        elif self.sliver_pub_ipv4 == 'dhcp':
+        elif self.sliver_pub_ipv4 == Node.DHCP:
             validate_dhcp_range(self.sliver_pub_ipv4_range)
-        elif self.sliver_pub_ipv4 == 'range':
+        elif self.sliver_pub_ipv4 == Node.RANGE:
             validate_ipv4_range(self.sliver_pub_ipv4_range)
         super(Node, self).clean()
     
@@ -169,11 +170,6 @@ class Node(models.Model):
         self.update_set_state(commit=False)
         super(Node, self).save(*args, **kwargs)
     
-    @property
-    @cached
-    def mgmt_net(self):
-        return get_mgmt_backend_class()(self)
-    
     def reboot(self):
         self.boot_sn += 1
         self.save()
@@ -282,11 +278,6 @@ class Server(SingletonModel):
     
     def __unicode__(self):
         return 'Server'
-    
-    @property
-    @cached
-    def mgmt_net(self):
-        return get_mgmt_backend_class()(self)
 
 
 class ServerProp(BaseProp):
